import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import '../../cherry_flutter.dart';

class CHFOutlineBorderField extends StatelessWidget {
  final TextEditingController controller;
  final double? height;
  final String? title;
  final double? titleSize;
  final String? hintText;
  final String type;
  final bool clearable;
  final bool showEyes;
  final bool required;
  final bool enable;
  final double? titleSpace;
  final Widget? prefixWidget;
  final Widget? suffixWidget;
  final double? contentPaddingHorizontal;
  final TextInputType? keyboardType;
  final List<TextInputFormatter>? inputFormatters;
  final ValueChanged<String>? onChanged;
  final VoidCallback? onClearable;
  final GestureTapCallback? onTap;
  final bool readonly;

  const CHFOutlineBorderField({
    Key? key,
    required this.controller,
    this.height,
    this.title,
    this.titleSize,
    this.hintText,
    this.type = 'text',
    this.clearable = false,
    this.showEyes = false,
    this.required = false,
    this.enable = true,
    this.titleSpace,
    this.prefixWidget,
    this.suffixWidget,
    this.contentPaddingHorizontal,
    this.keyboardType,
    this.inputFormatters,
    this.onChanged,
    this.onClearable,
    this.readonly = false, this.onTap,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        if (title != null)
          Container(
            margin: EdgeInsets.only(bottom: titleSpace ?? 10),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                Text(
                  title!,
                  style:
                      TextStyle(fontSize: titleSize ?? 12, color: const Color(0xff111111)),
                ),
                if (required)
                  Text('*',
                      style: TextStyle(
                          fontSize: titleSize ?? 12, color: const Color(0xffB3272A)))
              ],
            ),
          ),
        CHField(
          onTap: onTap,
          onChanged: onChanged,
          onClearable: onClearable,
          controller: controller,
          height: height ?? 44,
          type: type,
          readonly: readonly,
          clearable: clearable,
          enabled: enable,
          showEyes: showEyes,
          hintText: hintText,
          prefixWidget: prefixWidget,
          suffixWidget: suffixWidget,
          contentPaddingHorizontal: contentPaddingHorizontal,
          style: TextStyle(fontSize: 14, color: const Color(0xff111111)),
          hintStyle: TextStyle(
              fontSize: 14, color: const Color(0xffCCCCCC), height: 1),
          enabledBorder: OutlineInputBorder(
              borderRadius: BorderRadius.circular(1),
              borderSide: BorderSide(width: 1, color: const Color(0xffEEEEEE))),
          focusBorder: OutlineInputBorder(
              borderRadius: BorderRadius.circular(1),
              borderSide:
                  BorderSide(width: 1, color: Theme.of(context).primaryColor)),
        ),
      ],
    );
  }
}

class CHFUnderlineField extends StatelessWidget {
  final TextEditingController controller;
  final double? height;
  final String? title;
  final double? titleSize;
  final String? hintText;
  final String type;
  final bool clearable;
  final bool showEyes;
  final bool readonly;
  final bool required;
  final bool enabled;
  final double? titleSpace;
  final Widget? prefixWidget;
  final Widget? suffixWidget;
  final double? contentPaddingHorizontal;
  final TextInputType? keyboardType;
  final List<TextInputFormatter>? inputFormatters;
  final ValueChanged<String>? onChanged;
  final VoidCallback? onClearable;
  final GestureTapCallback? onTap;

  const CHFUnderlineField({
    Key? key,
    required this.controller,
    this.height,
    this.title,
    this.titleSize,
    this.hintText,
    this.type = 'text',
    this.clearable = false,
    this.showEyes = false,
    this.readonly = false,
    this.required = false,
    this.enabled = true,
    this.titleSpace,
    this.prefixWidget,
    this.suffixWidget,
    this.contentPaddingHorizontal,
    this.keyboardType,
    this.inputFormatters,
    this.onChanged,
    this.onClearable, this.onTap,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        if (title != null)
          Container(
            margin: EdgeInsets.only(bottom: titleSpace ?? 0.0),
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                Text(
                  title!,
                  style:
                      TextStyle(fontSize: titleSize ?? 12, color: const Color(0xff111111)),
                ),
                if (required)
                  Text(
                    '*',
                    style: TextStyle(
                      fontSize: titleSize ?? 12,
                      color: const Color(0xffB3272A),
                    ),
                  )
              ],
            ),
          ),
        CHField(
          onTap: onTap,
          onChanged: onChanged,
          onClearable: onClearable,
          controller: controller,
          height: height ?? 44,
          type: type,
          hintText: hintText,
          clearable: clearable,
          showEyes: showEyes,
          readonly: readonly,
          enabled: enabled,
          prefixWidget: prefixWidget,
          suffixWidget: suffixWidget,
          keyboardType: keyboardType,
          inputFormatters: inputFormatters,
          contentPaddingHorizontal: contentPaddingHorizontal ?? 0,
          style: TextStyle(fontSize: 14, color: const Color(0xff333333)),
          hintStyle: TextStyle(
              fontSize: 14, color: const Color(0xffCCCCCC), height: 1),
          enabledBorder: UnderlineInputBorder(
              borderSide: BorderSide(width: 1, color: const Color(0xffEEEEEE))),
          focusBorder: UnderlineInputBorder(
              borderSide:
                  BorderSide(width: 1, color: Theme.of(context).primaryColor)),
        ),
      ],
    );
  }
}
